#
# spec file for package python-pytest-astropy-header
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%define modname pytest-astropy-header

Name:           python-%{modname}%{psuffix}
Version:        0.2.2
Release:        2.1
Summary:        Pytest plugin to add diagnostic information to the header of the test output
License:        BSD-3-Clause
URL:            https://github.com/astropy/pytest-astropy-header
Source:         https://files.pythonhosted.org/packages/source/p/%{modname}/%{modname}-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 30.3.0}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-pytest >= 4.6
%if %{with test}
BuildRequires:  %{python_module astropy >= 4.0}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pytest >= 4.6}
%endif
Provides:       python-pytest_astropy_header = %{version}-%{release}
BuildArch:      noarch
%python_subpackages

%description
This plugin package provides a way to include information about the system,
Python installation, and select dependencies in the header of the output when
running pytest. It can be used with packages that are not affiliated with the
Astropy project, but is optimized for use with astropy-related projects.

%prep
%autosetup -p1 -n %{modname}-%{version}

%build
%pyproject_wheel

%install
%if !%{with test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
# multibuild: nothing has been installed, test the source directory
export PYTHONPATH=$(pwd)
%pytest
%endif

%if !%{with test}
%files %{python_files}
%doc CHANGES.rst README.rst
%license LICENSE.rst
%{python_sitelib}/pytest_astropy_header
%{python_sitelib}/pytest_astropy_header-%{version}.dist-info
%endif

%changelog
* Wed May  7 2025 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
* Thu Oct 27 2022 Ben Greiner <code@bnavigator.de>
- Update to v0.2.2
  * The plugin is now aware of the ``run_slow`` and ``run_hugemem``
    options introduced in ``pytest-astropy`` version 0.10.0. [#48]
* Sun Mar 13 2022 Ben Greiner <code@bnavigator.de>
- Update to v0.2.1
  * Import astropy so astropy can use this package by @pllim in #43
* Tue Dec 28 2021 Ben Greiner <code@bnavigator.de>
- Update to v0.2
  * Suppressed PytestAssertRewriteWarning. [#4]
  * Do not show astropy-helpers version in packages that don't use
    it. [#16]
  * Removed compatibility code for astropy < 4.0, and for
    astropy-helpers. [#32]
  * Removed astropy dependency. [#19, #34]
  * Bumped minimum supported Python version to 3.7 and various
    infrastructure updates. [#23, #39]
- Drop patches
  * pytest-astropy-header-pr16-no-helper-version.patch
  * pytest-astropy-header-pr29-nohelpers.patch
* Wed Dec  9 2020 Benjamin Greiner <code@bnavigator.de>
- Fix test failures
  * requires astropy >= 4 which removed astropy-helpers
  * gh#/astropy/pytest-astropy-header#16
    pytest-astropy-header-pr16-no-helper-version.patch
  * gh#/astropy/pytest-astropy-header#29
    pytest-astropy-header-pr29-nohelpers.patch
* Sun Aug 16 2020 Benjamin Greiner <code@bnavigator.de>
- Fix test failures by testing the source directory in multibuild
* Fri Jan 10 2020 Tomáš Chvátal <tchvatal@suse.com>
- Switch to multibuild to avoid cycles
- Reduce the tests dependencies to match reality
* Thu Dec 19 2019 Benjamin Greiner <code@bnavigator.de>
- update to version 0.1.2
  - Handle the case where the astropy version is 'unknown'. [#11]
  - Fix declaration of test dependencies. [#9]
- changes on version 0.1.1:
  - Make plugin not crash if astropy is not installed. [#1]
- remove obsolete pytest-astropy-header-pr2.patch
- require astropy >= 3.0 because astropy-helpers is not found
* Wed Dec 11 2019 code@bnavigator.de
- pytest-astropy-header-pr2.patch: fix import error due to
  reversed dependency (upstream PR#2 fixing issue#6)
* Wed Dec 11 2019 Benjamin Greiner <code@bnavigator.de>
- initial specfile, version 0.1
